@@ -19,9 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include <string.h>
 
@@ -92,7 +90,10 @@ struct _PeasExtensionSetPrivate {
   PeasEngine *engine;
   GType exten_type;
   guint n_parameters;
+
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   GParameter *parameters;
+  G_GNUC_END_IGNORE_DEPRECATIONS
 
   GQueue extensions;
 };
@@ -104,7 +105,10 @@ typedef struct {
 
 typedef struct {
   guint n_parameters;
+
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   GParameter *parameters;
+  G_GNUC_END_IGNORE_DEPRECATIONS
 } PeasParameterArray;
 
 /* Signals */
@@ -142,7 +146,10 @@ set_construct_properties (PeasExtensionSet   *set,
 
   priv->n_parameters = array->n_parameters;
 
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   priv->parameters = g_new0 (GParameter, array->n_parameters);
+  G_GNUC_END_IGNORE_DEPRECATIONS
+
   for (i = 0; i < array->n_parameters; i++)
     {
       priv->parameters[i].name = g_intern_string (array->parameters[i].name);
@@ -604,6 +611,8 @@ peas_extension_set_foreach (PeasExtensionSet            *set,
     }
 }
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+
 /**
  * peas_extension_set_newv: (rename-to peas_extension_set_new)
  * @engine: (allow-none): A #PeasEngine, or %NULL.
@@ -691,6 +700,8 @@ peas_extension_set_new_valist (PeasEngine  *engine,
   return set;
 }
 
+G_GNUC_END_IGNORE_DEPRECATIONS
+
 /**
  * peas_extension_set_new: (skip)
  * @engine: (allow-none): A #PeasEngine, or %NULL.
